==> ejc-zdsmaterialb-api-3.0.0-20241014.032806-28-sources.jar: com/ejianc/business/zdsmaterial/material/vo/TaxCategoryVO.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 税收分类档案
 *
 * @author generator
 *
 */
public class TaxCategoryVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long orgId; // 单据组织id
    private String orgCode; // 单据组织编码
    private String orgName; // 单据组织名称
    private String billCode; // 单据编码
    private Integer billState; // 单据状态（审批必须字段）
    private Long createUserId; // 制单人Id
    private String categoryName; // 分类名称
    private BigDecimal taxRate; // 税率
    private BigDecimal preTaxRate; // 预缴税率
    private String memo; // 备注
    private String categoryCode; // 分类编码

    private List<Long> ids;

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getPreTaxRate() {
        return preTaxRate;
    }

    public void setPreTaxRate(BigDecimal preTaxRate) {
        this.preTaxRate = preTaxRate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }
}

==> ejc-zdsmaterialb-api-3.0.0-20250808.071759-54-sources.jar: com/ejianc/business/zdsmaterial/material/vo/TaxCategoryVO.java <==
package com.ejianc.business.zdsmaterial.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 税收分类档案
 *
 * @author generator
 *
 */
public class TaxCategoryVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long orgId; // 单据组织id
    private String orgCode; // 单据组织编码
    private String orgName; // 单据组织名称
    private String billCode; // 单据编码
    private Integer billState; // 单据状态（审批必须字段）
    private Long createUserId; // 制单人Id
    private String categoryName; // 分类名称
    private BigDecimal taxRate; // 税率
    private BigDecimal preTaxRate; // 预缴税率
    private String memo; // 备注
    private String categoryCode; // 分类编码
    private Integer sequence; // 排序号
    private List<Long> ids;

    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getPreTaxRate() {
        return preTaxRate;
    }

    public void setPreTaxRate(BigDecimal preTaxRate) {
        this.preTaxRate = preTaxRate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }
}
